console.log(/*#__PURE__*/ React.createElement("h1", {
    value: "abc as"
}, "s"));
